# TODO
# - shared lib is not versioned
# - can't build shared and static in same build. drop shared bcond
#
# Conditional build:
%bcond_without	fuse		# Build fuse mount helper
%bcond_without	qt			# Build reference Qt application
%bcond_without	shared		# Build shared library
%bcond_with	static_libs	# don't build static libraries

# build doesn't support both
%if %{with shared}
%undefine static_libs
%endif

Summary:	Android File Transfer for Linux
Name:		android-file-transfer
Version:	3.4
Release:	2
License:	LGPLv2.1
Group:		X11/Applications
Source0:	https://github.com/whoozle/android-file-transfer-linux/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	691142fdbea216676df27bfc94885f71
URL:		https://whoozle.github.io/android-file-transfer-linux/
BuildRequires:	build-essential
BuildRequires:	cmake >= 2.8
%{?with_fuse:BuildRequires:	libfuse-devel}
BuildRequires:	libmagic-devel
BuildRequires:	libstdc++-devel
BuildRequires:	ninja
BuildRequires:	pkgconfig
BuildRequires:	readline-devel
BuildRequires:	rpmbuild(macros) >= 1.727
%if %{with qt}
BuildRequires:	Qt5Widgets-devel
BuildRequires:	qt5-build
BuildRequires:	qt5-qmake
%endif
%if %{with shared}
Requires:	%{name}-libs = %{version}-%{release}
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Android File Transfer for Linux - reliable MTP client with
minimalistic UI similar to Android File Transfer for Mac.

Features:
- Simple Qt UI with progress dialogs.
- FUSE wrapper (If you'd prefer mounting your device), supporting
  partial read/writes, allowing instant access to your files.
- No file size limits.
- Automatically renames album cover to make it visible from media
  player.
- USB 'Zerocopy' support found in recent Linux kernel (no user/kernel
  data copying)
- No extra dependencies (e.g. libptp/libmtp).
- Available as static/shared library.
- Command line tool (aft-mtp-cli)

%package libs
Summary:	Shared %{name} library
Group:		Libraries

%description libs
Shared %{name} library.

%package static
Summary:	Static %{name} library
Summary(pl.UTF-8):	Statyczna biblioteka %{name}
Group:		Development/Libraries

%description static
Static %{name} library.

%description static -l pl.UTF-8
Statyczna biblioteka %{name}.

%package fuse
Summary:	aft-mtp-mount fuse wrapper
Group:		Applications
%if %{with shared}
Requires:	%{name}-libs = %{version}-%{release}
%endif

%description fuse
FUSE wrapper (If you'd prefer mounting your device), supporting
partial read/writes, allowing instant access to your files.

%package qt
Summary:	Qt GUI
Group:		X11/Applications
%if %{with shared}
Requires:	%{name}-libs = %{version}-%{release}
%endif
Requires:	desktop-file-utils
Requires:	gtk-update-icon-cache
Requires:	hicolor-icon-theme

%description qt
Qt GUI.

%prep
%setup -q -n %{name}-linux-%{version}

%build
install -d build
cd build
%cmake -G Ninja \
	-DBUILD_FUSE=%{!?with_fuse:OFF}%{?with_fuse:ON} \
	-DBUILD_QT_UI=%{!?with_qt:OFF}%{?with_qt:ON} \
	-DBUILD_SHARED_LIB=%{!?with_shared:OFF}%{?with_shared:ON} \
	..
%ninja_build

%install
rm -rf $RPM_BUILD_ROOT
%ninja_install -C build

%clean
rm -rf $RPM_BUILD_ROOT

%post qt
%update_desktop_database
%update_icon_cache hicolor

%postun qt
%update_desktop_database
%update_icon_cache hicolor

%files
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/aft-mtp-cli

%if %{with fuse}
%files fuse
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/aft-mtp-mount
%endif

%if %{with qt}
%files qt
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/android-file-transfer
%{_desktopdir}/android-file-transfer.desktop
%{_iconsdir}/hicolor/*/apps/android-file-transfer.png
%{_datadir}/metainfo/android-file-transfer.appdata.xml
%endif

%if %{with shared}
%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libmtp-ng.so
%endif

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libmtp-ng-static.a
%endif
%changelog
* Thu Oct 17 2019 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/android-file-transfer.git;a=log;h=master

* Thu Oct 17 2019 Arkadiusz Miśkiewicz <arekm@maven.pl> 980259f
- release 2 (by relup.sh)

* Thu Jul 19 2018 Elan Ruusamäe <glen@pld-linux.org> b7603c6
- fuse, cli, qt seem to work; rel 1

* Thu Jul 19 2018 Elan Ruusamäe <glen@pld-linux.org> d8b9bd5
- desktop deps for qt package

* Thu Jul 19 2018 Elan Ruusamäe <glen@pld-linux.org> 724bec8
- add fuse subpackage

* Thu Jul 19 2018 Elan Ruusamäe <glen@pld-linux.org> 0c55280
- adjust deps, files for qt bcond

* Thu Jul 19 2018 Elan Ruusamäe <glen@pld-linux.org> 8b71ca8
- add fuse,qt,shared bconds; -libs, -static subpackages

* Thu Jul 19 2018 Elan Ruusamäe <glen@delfi.ee> 6c6c375
- update deps (cleanbuild)

* Thu Jul 19 2018 Elan Ruusamäe <glen@pld-linux.org> 010acf0
- new, version 3.4

